@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.13';
+$VERSION = '0.14';
 
 #--------------------------------------------------------------------------
 
@@ -139,7 +139,7 @@ sub search {
     ($data->{thumb})                    = $html =~ m!(http://covers.booktopia.com.au/\d+/[-\w]+\.jpg)!si;
     ($data->{isbn13})                   = $html =~ m!<b>\s*ISBN:\s*</b>\s*(\d+)!si;
     ($data->{isbn10})                   = $html =~ m!<b>\s*ISBN-10:\s*</b>\s*(\d+)!si;
-    ($data->{author})                   = $html =~ m!<span class="bold">(?:By|Author):\s*</span><span style="color:#FFFFFF">((?:<a[^>]+href="/search.ep\?author=[^"]+"[^>]*>[^<]+</a>[,\s]*)+)</span><br/>!si;
+    ($data->{author})                   = $html =~ m!<span class="bold">(?:By|Author):\s*</span><span[^>]*>((?:<a[^>]+href="/search.ep\?author=[^"]+"[^>]*>[^<]+</a>[,\s]*)+)</span><br/>!si;
     ($data->{title})                    = $html =~ m!<meta property="og:title" content="([^"]+)"!si;
     ($data->{title})                    = $html =~ m!<a href="[^"]+" class="largeLink">([^<]+)</a><br/><br/>!si  unless($data->{title});
     ($data->{description})              = $html =~ m!<div id="product-description">(.*?)</div>\s*<div id="(?:details|extract)"!si;
